@@ -16,11 +16,9 @@ Evo::Comp
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
-=head1 DESCRIPTION
-
-=head2 Component-oriented programming
+=head1 Component-oriented programming
 
 A new promising component-oriented programming concepts. Documentation will be available if someone will be willing to help write it.
 
@@ -36,66 +34,34 @@ The most problems with Moose like modules is with initialization. Let's take a l
   my $obj = My::Moose->new(fo => 3);
   print $obj->foo;
 
-As you can see, we passed C<fo> instead of C<foo>, and Moose silently ignored it. You should write a huge amout of extra tests to pervent such errors.
+As you can see, we passed C<fo> instead of C<foo>, and Moose silently ignored it.  You should write a huge amout of extra tests to pervent such errors. So I decided to write all the stuff and name it component oriented programming.
 
-Also traditional OO programming suffers the fragile base class problems (use Google). To solve it, component oriented C<Evo::Comp> introduces flexible component roles L<Evo::Comp::Role>. 
+More explanation will be written later
 
-So I decided to write all the stuff and name it component oriented programming. More explanation will be written later
-
-=head1 SYNOPSYS
-
-  package main;
-  use Evo;
-
-  {
-
-    package My::Human;
-    use Evo '-Comp *';
-
-    has 'name' => 'unnamed';
-    has 'gender', is => 'ro', required => 1;
-    has age => check => sub($v) { $v >= 18 };
-  }
-
-  my $alex = My::Human::new(gender => 'male');
-
-  # default value "unnamed"
-  say $alex->name;
-
-  # fluent design
-  $alex->name('Alex')->age(18);
-  say $alex->name, ': ', $alex->age;
-
-  # will die, gender is required
-  My::Human::new();
-
-  # will die, age must be >= 18
-  My::Human::new(age => 17, gender => 'male');
-  My::Human::new()->age(17, gender => 'male');
-
-=head1 Usage
-
-=head2 creating component
-
-Describe a component, use need to import "*" to get it worked
+=head2 Usage
 
   package My::Comp;
   use Evo '-Comp *';
   has 'simple';
+  has read_only => is => 'ro';
 
-You don't need to call something like C<__PACKAGE__-E<gt>meta-E<gt>make_immutable> unlike in L<Moose>, components are fast enough by design.
+  package main;
+  use Evo;
+  # if My::Comp in separate file
+  # use My::Comp;
+  
+  # !!!pay attantion, not My::Foo->new
+  my $foo = My::Foo::new(important => '22', read_only => 'hi');
+  $foo->simple('hello')->important(44);
+  say $foo->simple;
 
-=head2 new
+We're protected from common mistakes
 
-B<important!!!>
-Because Components reuse code horizontal, there's no need to pass the class string to every invocation of C<new> (or C<Evo::Comp::Out/"init">). So instead of C<My::Class-E<gt>new> use C<My::Comp::new>
+  # "SiMple" is unknown
+  my $foo = My::Foo::new(SiMple => 1, important => 1);
 
-  my $foo = My::Comp::new(simple => 1);
-  my $foo2 = My::Comp::new();
-
-We're protected from common mistakes, because constructor won't accept unknown attributes
-
-  my $foo = My::Comp::new(SiMple => 1);
+  # "important" is required
+  my $foo = My::Foo::new();
 
 =head2 Storage
 
@@ -162,6 +128,7 @@ You can also return C<(0, "CustomError")> to provide more expressive explanation
 
     package My::Foo;
     use Evo '-Comp *';
+    use Evo -Modern;
 
     has big => check => sub($val) { $val > 10 ? 1 : (0, "not > 10"); };
   };
@@ -171,20 +138,97 @@ You can also return C<(0, "CustomError")> to provide more expressive explanation
   $foo->big(9);    # will die
   my $bar = My::Foo::new(big => 9);    # will die
 
-=head1 Code reuse
+=head2 Code reuse (Roles)
 
-Instead of OO inheritance, wich suffers from fragile base class problem, C<Evo::Comp> provides L<Evo::Comp::Role>. This is a perfect choice for code reuse because of it's safety and flexibility. Look at L<Evo::Comp::Role> for more information
+!!! Below C<-Loaded> is only needed to copy-paste examples into one file and run it. In the real life code, where every role has separate file, it's unneccessary.
 
-=head2 with
+OO is considered an anti-pattern because it's hard to change and reuse such code, and every refactoring makes OO applications low-tested or extra-tested. Component oriented programming doesn't have such weakness. It uses roles (like Moose's roles), or so called "mixins".
 
-Load role and install all methods and attributes to the component. Supports L<Evo/"shortcuts">
+Because of that, Components are faster, simpler, and more reusable
+Also Roles can protect you from method and attributes clashing, because all methods and attributes will be installed into one file
+
+I'll write an article about this late (maybe)
+
+Here is a breaf overview
+
+  package main;
+  use Evo;
+
+  {
+
+    package Person::Human;
+    use Evo '-Comp::Role *; -Loaded';
+    has 'name';
+    sub upper_name : Role { uc shift->name }
+
+    package Person;
+    use Evo '-Comp *';
+
+    with ':Human';    # same as "Person::Human";
+    sub intro { say "My name is ", shift->upper_name }
+
+  };
+
+  my $alex = Person::new(name => 'alex');
+  $alex->intro;
+
+As you can see, role shares attributes and methods.
+To share method, add C<Role> tag. All attributes are shared automatically. In our case method C<upper_name> and attribute C<name> are provided by role.
+
+Let's separate C<Person::Human> into 2 different roles;
+
+  package main;
+  use Evo;
+
+  {
+
+    package Person::Human;
+    use Evo '-Comp::Role *; -Loaded';
+    has 'name';
+
+    package Person::LoudHuman;
+    use Evo '-Comp::Role *; -Loaded';
+
+    requires 'name';
+    sub upper_name : Role { uc shift->name }
 
     package Person;
     use Evo '-Comp *';
 
     with ':LoudHuman', ':Human';
+    sub intro { say "My name is ", shift->upper_name }
 
-Circular requirements can be solved by requiring roles in the single C<with>. See L<Evo::Comp::Role/"requires">
+  };
+
+  my $alex = Person::new(name => 'alex');
+  $alex->intro;
+
+Pay attention to the C<requires>.
+
+=head3 features
+
+=head4 role_gen
+
+Creates generator, very similar to L<Evo::Export/"export_gen">
+
+=head4 role_proxy
+
+  role_proxy 'My::Another', 'My::Another2';
+
+Proxy attributes and methods from one role to another
+
+=head4 role_methods
+
+C<:Role> attribute is preffered
+
+=head4 requires
+
+List method that should be available in component during role installation.
+If you require attribute, describe it before L</"with">. If you have circular dependencies, load all roles in the single L</"with">.
+
+=head4 with
+
+Load role and install all methods and attributes to the component
 
 =head1 AUTHOR
 
