@@ -14,7 +14,8 @@ my $GEN = {map { ($_, *{"gen_$_"}{CODE}) } qw(gs gsch gs_value gsch_value gs_cod
 
 sub GEN : Export {$GEN}
 
-sub gen_new($class, $opts) {
+sub gen_new {
+  my ($class, $opts) = @_;
 
   sub {
     my ($obj, %attrs) = @_;
@@ -37,7 +38,8 @@ sub gen_new($class, $opts) {
 }
 
 
-sub gen_gs($name) {
+sub gen_gs {
+  my ($name) = @_;
   sub {
     return $DATA{$_[0]}{$name} if @_ == 1;
     $DATA{$_[0]}{$name} = $_[1];
@@ -45,7 +47,8 @@ sub gen_gs($name) {
   };
 }
 
-sub gen_gs_value($name, $value) {
+sub gen_gs_value {
+  my ($name, $value) = @_;
   sub {
     return exists $DATA{$_[0]}{$name} ? $DATA{$_[0]}{$name} : $value if @_ == 1;
     $DATA{$_[0]}{$name} = $_[1];
@@ -53,7 +56,8 @@ sub gen_gs_value($name, $value) {
   };
 }
 
-sub gen_gs_code($name, $fn) {
+sub gen_gs_code {
+  my ($name, $fn) = @_;
   sub {
     return exists $DATA{$_[0]}{$name} ? $DATA{$_[0]}{$name} : $fn->($_[0]) if @_ == 1;
     $DATA{$_[0]}{$name} = $_[1];
@@ -62,7 +66,8 @@ sub gen_gs_code($name, $fn) {
 }
 
 
-sub gen_gsch($name, $ch) {
+sub gen_gsch {
+  my ($name, $ch) = @_;
   sub {
     return $DATA{$_[0]}{$name} if @_ == 1;
     my ($ok, $msg) = $ch->($_[1]);
@@ -72,7 +77,8 @@ sub gen_gsch($name, $ch) {
   };
 }
 
-sub gen_gsch_value($name, $ch, $value) {
+sub gen_gsch_value {
+  my ($name, $ch, $value) = @_;
   sub {
     return exists $DATA{$_[0]}{$name} ? $DATA{$_[0]}{$name} : $value if @_ == 1;
     my ($ok, $msg) = $ch->($_[1]);
@@ -82,7 +88,8 @@ sub gen_gsch_value($name, $ch, $value) {
   };
 }
 
-sub gen_gsch_code($name, $ch, $code) {
+sub gen_gsch_code {
+  my ($name, $ch, $code) = @_;
   sub {
     return exists $DATA{$_[0]}{$name} ? $DATA{$_[0]}{$name} : $code->($_[0]) if @_ == 1;
     my ($ok, $msg) = $ch->($_[1]);
@@ -105,7 +112,7 @@ Evo::Comp::Gen::HUF
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
