@@ -9,7 +9,8 @@ my $GEN = {map { ($_, *{"gen_$_"}{CODE}) } qw(gs gsch gs_value gsch_value gs_cod
 
 sub GEN : Export {$GEN}
 
-sub gen_new($class, $opts) {
+sub gen_new {
+  my ($class, $opts) = @_;
 
   sub {
     my %attrs = @_;
@@ -30,7 +31,8 @@ sub gen_new($class, $opts) {
 }
 
 
-sub gen_gs($name) {
+sub gen_gs {
+  my ($name) = @_;
   sub {
     return $_[0]->{$name} if @_ == 1;
     $_[0]->{$name} = $_[1];
@@ -38,7 +40,8 @@ sub gen_gs($name) {
   };
 }
 
-sub gen_gs_value($name, $value) {
+sub gen_gs_value {
+  my ($name, $value) = @_;
   sub {
     return exists $_[0]->{$name} ? $_[0]->{$name} : $value if @_ == 1;
     $_[0]->{$name} = $_[1];
@@ -46,7 +49,8 @@ sub gen_gs_value($name, $value) {
   };
 }
 
-sub gen_gs_code($name, $fn) {
+sub gen_gs_code {
+  my ($name, $fn) = @_;
   sub {
     return exists $_[0]->{$name} ? $_[0]->{$name} : $fn->($_[0]) if @_ == 1;
     $_[0]->{$name} = $_[1];
@@ -55,7 +59,8 @@ sub gen_gs_code($name, $fn) {
 }
 
 
-sub gen_gsch($name, $ch) {
+sub gen_gsch {
+  my ($name, $ch) = @_;
   sub {
     return $_[0]->{$name} if @_ == 1;
     my ($ok, $msg) = $ch->($_[1]);
@@ -65,7 +70,8 @@ sub gen_gsch($name, $ch) {
   };
 }
 
-sub gen_gsch_value($name, $ch, $value) {
+sub gen_gsch_value {
+  my ($name, $ch, $value) = @_;
   sub {
     return exists $_[0]->{$name} ? $_[0]->{$name} : $value if @_ == 1;
     my ($ok, $msg) = $ch->($_[1]);
@@ -75,7 +81,8 @@ sub gen_gsch_value($name, $ch, $value) {
   };
 }
 
-sub gen_gsch_code($name, $ch, $code) {
+sub gen_gsch_code {
+  my ($name, $ch, $code) = @_;
   sub {
     return exists $_[0]->{$name} ? $_[0]->{$name} : $code->($_[0]) if @_ == 1;
     my ($ok, $msg) = $ch->($_[1]);
@@ -99,7 +106,7 @@ Evo::Comp::Gen::Hash
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
