@@ -6,13 +6,15 @@ use Evo '::Meta';
 
 my $META = Evo::Comp::Meta::new(gen => GEN, rex => ROLE_EXPORTER);
 
-export_gen new => sub($class) { $META->compile_builder($class); };
+export_gen new => sub { $META->compile_builder(shift); };
 
-export_gen has => sub($class) {
+export_gen has => sub {
+  my $class = shift;
   sub { $META->install_attr($class, @_); };
 };
 
-export_gen with => sub($class) {
+export_gen with => sub {
+  my $class = shift;
   sub { $META->install_roles($class, @_); };
 };
 
@@ -31,7 +33,7 @@ Evo::Comp::Hash
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 DESCRIPTION
 
