@@ -8,12 +8,14 @@ my $META = Evo::Comp::Meta::new(gen => GEN, rex => ROLE_EXPORTER);
 
 export_gen init => sub { $META->compile_builder(shift); };
 
-export_gen has => sub($class) {
+export_gen has => sub {
+  my $class = shift;
   sub { $META->install_attr($class, @_); };
 };
 
 
-export_gen with => sub($class) {
+export_gen with => sub {
+  my $class = shift;
   sub { $META->install_roles($class, @_); };
 };
 
@@ -32,7 +34,7 @@ Evo::Comp::Out
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 DESCRIPTION
 
