@@ -8,12 +8,14 @@ use Module::Load;
 sub data { shift->{data} }
 sub new { bless {data => {}}, __PACKAGE__ }
 
-sub init_slot($self, $src, $name, $val) {
+sub init_slot {
+  my ($self, $src, $name, $val) = @_;
   croak "$src already adds $name" if $self->data->{$src}{export}{$name};
   $self->data->{$src}{export}{$name} = $val;
 }
 
-sub add_methods($self, $role, @methods) {
+sub add_methods {
+  my ($self, $role, @methods) = @_;
   no strict 'refs';    ## no critic
   foreach my $m (@methods) {
     my $full = "${role}::$m";
@@ -22,11 +24,13 @@ sub add_methods($self, $role, @methods) {
   }
 }
 
-sub add_gen($self, $role, $name, $gen) {
+sub add_gen {
+  my ($self, $role, $name, $gen) = @_;
   $self->init_slot($role, $name, {type => 'gen', value => $gen});
 }
 
-sub request_gen($self, $role, $name, $comp) {
+sub request_gen {
+  my ($self, $role, $name, $comp) = @_;
   my $slot = $self->data->{$role}{export}{$name}
     or croak qq#"$role" doesn't provide method "$name"#;
 
@@ -35,25 +39,29 @@ sub request_gen($self, $role, $name, $comp) {
   return $slot->{cache}{$comp} = $slot->{value}->($comp);
 }
 
-sub add_attr($self, $role, $name, @opts) {
+sub add_attr {
+  my ($self, $role, $name, @opts) = @_;
   Evo::Util::check_subname($name) || croak(qq{Attribute "$name" invalid});
   $self->init_slot($role, $name, {type => 'attr', value => \@opts});
 }
 
-sub _map($self, $type, $role) {
+sub _map {
+  my ($self, $type, $role) = @_;
   my $all = $self->data->{$role}{export};
   map { ($_, $all->{$_}->{value}) } grep { $all->{$_}->{type} eq $type } keys %$all;
 }
 
-sub methods($self, $role, $comp) {
+sub methods {
+  my ($self, $role, $comp) = @_;
   my %gens = $self->_map('gen', $role);
   my %gms = map { $_ => $gens{$_}->($comp) } keys %gens;
   (%gms, $self->_map('method', $role),);
 }
 
-sub attrs($self, $role) { $self->_map('attr', $role); }
+sub attrs { shift->_map('attr', shift); }
 
-sub hooks($self, $role, @hooks) {
+sub hooks {
+  my ($self, $role, @hooks) = @_;
 
   return $self->data->{$role}
     && $self->data->{$role}{hooks} ? ($self->data->{$role}{hooks}->@*) : ()
@@ -61,7 +69,8 @@ sub hooks($self, $role, @hooks) {
   push @{($self->data->{$role}{hooks} ||= [])}, @hooks;
 }
 
-sub proxy($self, $dst, $src) {
+sub proxy {
+  my ($self, $dst, $src) = @_;
   load $src;
 
   my $data_src = $self->data->{$src} || {};
@@ -92,7 +101,7 @@ Evo::Comp::Role::Exporter
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
