@@ -3,7 +3,8 @@ use Evo;
 use Evo::Export '*';
 use Carp 'croak';
 
-sub croak_bad_value($value, $name, $msg=undef) : Export {
+sub croak_bad_value : Export {
+  my ($value, $name, $msg) = @_;
   my $err = qq'Bad value "$value" for attribute "$name"';
   $err .= ": $msg" if $msg;
   croak $err;
@@ -23,7 +24,7 @@ Evo::Comp::Util
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
