@@ -1,16 +1,13 @@
 package Evo::Default;
 use strict;
 use warnings;
+use feature ();
 
 sub import {
   $_->import for qw(strict warnings utf8);
-  feature::->import(':5.22');
-
+  feature::->import(':5.20');
   feature::->import('postderef');
   warnings::->unimport('experimental::postderef');
-
-  feature::->import('signatures');
-  warnings::->unimport('experimental::signatures');
 }
 
 1;
@@ -27,7 +24,7 @@ Evo::Default
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 DESCRIPTION
 
