@@ -11,7 +11,8 @@ sub new { bless {data => {}}, __PACKAGE__ }
 
 sub data { shift->{data} }
 
-sub install($self, $src, $dst, @xlist) {
+sub install {
+  my ($self, $src, $dst, @xlist) = @_;
   my @list = $self->expand_wildcards($src, @xlist);
 
   my %patch;
@@ -25,7 +26,8 @@ sub install($self, $src, $dst, @xlist) {
   Evo::Util::monkey_patch $dst, %patch;
 }
 
-sub request_gen($self, $epkg, $name, $dpkg) {
+sub request_gen {
+  my ($self, $epkg, $name, $dpkg) = @_;
   my $slot = $self->find_slot($epkg, $name);
 
   # it's important to return same function for the same module
@@ -34,25 +36,31 @@ sub request_gen($self, $epkg, $name, $dpkg) {
 }
 
 # traverse to find gen via links, return Module, name, gen
-sub find_slot($self, $pkg, $name) {
+sub find_slot {
+  my ($self, $pkg, $name) = @_;
   croak qq{"$pkg" doesn't export "$name"} unless my $slot = $self->data->{$pkg}{$name};
 }
 
-sub init_slot($self, $src, $name, $val) {
+sub init_slot {
+  my ($self, $src, $name, $val) = @_;
   croak "$src already exports $name" if $self->data->{$src}{$name};
   $self->data->{$src}{$name} = $val;
 }
 
-sub add_proxy($self, $epkg, $ename, $spkg, $sname) {
+sub add_proxy {
+  my ($self, $epkg, $ename, $spkg, $sname) = @_;
   my $slot = $self->find_slot($spkg, $sname);
+
   $self->init_slot($epkg, $ename, $slot);
 }
 
-sub add_gen($self, $src, $name, $gen) {
+sub add_gen {
+  my ($self, $src, $name, $gen) = @_;
   $self->init_slot($src, $name, {gen => $gen});
 }
 
-sub add_sub($self, $src, $name_as) {
+sub add_sub {
+  my ($self, $src, $name_as) = @_;
   my ($name, $as) = split ':', $name_as;
   $as ||= $name;
   my $full = "${src}::$name";
@@ -61,7 +69,8 @@ sub add_sub($self, $src, $name_as) {
   $self->add_gen($src, $as, sub {$sub});
 }
 
-sub proxy($self, $epkg, $spkg, @xlist) {
+sub proxy {
+  my ($self, $epkg, $spkg, @xlist) = @_;
   $spkg = Evo::Util::resolve_package(scalar caller, $spkg);
   load $spkg;
   my @list = $self->expand_wildcards($spkg, @xlist);
@@ -74,7 +83,8 @@ sub proxy($self, $epkg, $spkg, @xlist) {
 
 }
 
-sub expand_wildcards($self, $src, @list) {
+sub expand_wildcards {
+  my ($self, $src, @list) = @_;
   croak "Empty list" unless @list;
 
   my $data = $self->data->{$src};
@@ -109,7 +119,7 @@ Evo::Export::Exporter
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
