@@ -1,5 +1,5 @@
 package Evo::Lib;
-use Evo '-Export *', -Util;
+use Evo '-Export *', -Util, 'Carp croak';
 use Time::HiRes qw(CLOCK_MONOTONIC clock_gettime);
 
 PATCH: {
@@ -8,7 +8,7 @@ PATCH: {
   *Evo::Lib::monkey_patch = *Evo::Util::monkey_patch{CODE};
 }
 
-export qw(debug monkey_patch);
+export qw(debug context_result monkey_patch);
 
 my $HAS_M_TIME = eval { clock_gettime(CLOCK_MONOTONIC); 1 };
 
@@ -16,6 +16,13 @@ export_anon steady_time => $HAS_M_TIME
   ? sub { clock_gettime(CLOCK_MONOTONIC); }
   : \&Time::HiRes::time;
 
+sub context_result($) {
+  return unless $_[0];
+  return if !defined $_[0][0];
+  $_[0][0] ? (@{$_[0][1]}) : $_[0][1];
+}
+
+
 sub ws_combine : Export {
   return unless @_;
   return $_[0] if @_ == 1;
@@ -41,7 +48,7 @@ Evo::Lib
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
