@@ -10,10 +10,11 @@ has tick_time => \&steady_time, is => 'rw';
 with 'Evo::Loop::Role::Zone', 'Evo::Loop::Role::Timer', 'Evo::Loop::Role::Handle',
   'Evo::Loop::Role::Postpone';
 
-sub update_tick_time { shift->tick_time(steady_time()); }
+sub update_tick_time { $_[0]->tick_time(steady_time()); }
 
 # return number of event, or 0 if no events left and we can stop
-sub tick($self) {
+sub tick {
+  my $self = shift;
   $self->update_tick_time();
 
   my $handle_count   = $self->handle_count;
@@ -29,7 +30,8 @@ sub tick($self) {
 }
 
 # sleep in usleep or in handle_process. Assumming there is at least some event
-sub maybe_sleep($self) {
+sub maybe_sleep {
+  my $self = shift;
   $self->update_tick_time;
   my ($tc, $sc) = ($self->timer_count(), $self->handle_count());
 
@@ -43,7 +45,7 @@ sub maybe_sleep($self) {
 }
 
 
-sub start($self) { $self->maybe_sleep while $self->tick; }
+sub start { $_[0]->maybe_sleep while $_[0]->tick; }
 
 1;
 
@@ -59,7 +61,7 @@ Evo::Loop::Comp
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
