@@ -12,21 +12,24 @@ has timer_queue => sub { [] };
 
 sub timer_count : Role { scalar $_[0]->timer_queue->@* }
 
-sub timer($self, $after, $cb) : Role {
-  my $zcb = $self->zone_cb($cb);
+sub timer : Role {
+  my ($self, $after) = (shift, shift);
+  my $zcb = $self->zone_cb(shift);
 
   push $self->timer_need_sort(1)->timer_queue->@*, my $slot = [$self->tick_time + $after, $zcb];
   $slot;
 }
 
-sub timer_remove($self, $ref) : Role {
+sub timer_remove : Role {
+  my ($self, $ref) = @_;
   my $que = $self->timer_queue;
 
   defined(my $index = first { $que->[$_] == $ref } 0 .. $#$que) or return;
   splice $que->@*, $index, 1;
 }
 
-sub timer_sort_if_needed($self) : Role {
+sub timer_sort_if_needed : Role {
+  my $self = shift;
   return unless $self->timer_need_sort;
   my $timer_queue = $self->timer_queue;
   $timer_queue->@* = sort { $a->[0] <=> $b->[0] } $timer_queue->@*;
@@ -36,7 +39,8 @@ sub timer_sort_if_needed($self) : Role {
 # queue is a list of unsorted timers. Queue becomes sorted at the beginning.
 # Adding timer makes queue unsorted again.
 # because timers are sorted, process till first future timer
-sub timer_process($self) : Role {
+sub timer_process : Role {
+  my $self = shift;
   $self->timer_sort_if_needed();
   my $time        = $self->tick_time;
   my $timer_queue = $self->timer_queue;
@@ -47,7 +51,8 @@ sub timer_process($self) : Role {
 # calculates a timeout the app can sleep without missing timer
 # assumes that have at least one timer. Calls sort_if_needed
 # returns ms (1s/1000), >=0
-sub timer_calculate_timeout($self) : Role {
+sub timer_calculate_timeout : Role {
+  my $self = shift;
   $self->timer_sort_if_needed();
   my $timeout = ($self->timer_queue->[0][0] - $self->tick_time);
   return $timeout > 0 ? $timeout : 0;
@@ -67,7 +72,7 @@ Evo::Loop::Role::Timer
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
