@@ -13,7 +13,8 @@ sub zone : Role {
   $fn->();
 }
 
-sub zone_cb($self, $cb) : Role {
+sub zone_cb : Role {
+  my ($self, $cb) = @_;
   my $data = $self->zone_data;
   my $w    = $data->{w};
 
@@ -43,7 +44,7 @@ Evo::Loop::Role::Zone
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
