@@ -2,9 +2,9 @@ package Evo::Promises;
 use Evo;
 use Evo '-Export *; :Deferred; :Promise';
 
-sub promise($fn) : Export {
+sub promise : Export {
   my $d = Evo::Promises::Deferred::new(promise => my $p = Evo::Promises::Promise::new());
-  $fn->(sub { $d->resolve(@_) }, sub { $d->reject(@_) });
+  shift->(sub { $d->resolve(@_) }, sub { $d->reject(@_) });
   $p;
 }
 
@@ -25,7 +25,7 @@ Evo::Promises
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
