@@ -4,14 +4,16 @@ use Evo '-Comp *';
 has 'promise', required => 1, is => 'ro';
 has 'called';
 
-sub reject($self, $r) {
+sub reject {
+  my ($self, $r) = @_;
   return if $self->called;
   $self->called(1)->promise->d_reject_continue($r);
 }
 
-sub resolve($self, $v) {
+sub resolve {
+  my ($self, $r) = @_;
   return if $self->called;
-  $self->called(1)->promise->d_resolve_continue($v);
+  $self->called(1)->promise->d_resolve_continue($r);
 }
 
 1;
@@ -28,7 +30,7 @@ Evo::Promises::Deferred
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
