@@ -4,21 +4,24 @@ use Evo '-Comp *';
 has 'promise', required => 1, is => 'ro';
 has $_ for qw(called v blocking should_resolve);
 
-sub reject($self, $r) {
+sub reject {
+  my ($self, $r) = @_;
   return if $self->called;
   $self->called(1);
   $self->blocking ? $self->promise->d_reject($r) : $self->promise->d_reject_continue($r);
   $self;
 }
 
-sub resolve($self, $v) {
+sub resolve {
+  my ($self, $v) = @_;
   return if $self->called;
   $self->called(1);
   $self->blocking ? $self->should_resolve(1)->v($v) : $self->promise->d_resolve_continue($v);
   $self;
 }
 
-sub try_thenable($self, $thenable) {
+sub try_thenable {
+  my ($self, $thenable) = @_;
   $self->blocking(1);
 
   # reject drain second time, so don't bother checking "called"
@@ -41,7 +44,7 @@ Evo::Promises::Sync
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head2 SYNOPSIS
 This class exists for internal purposes only to make C<d_resolve> a little bit
