@@ -7,20 +7,23 @@ use constant {PENDING => 'PENDING', REJECTED => 'REJECTED', FULFILLED => 'FULFIL
 
 export qw(PENDING REJECTED FULFILLED);
 
-sub is_locked_in($parent, $child) : Export {
+sub is_locked_in : Export {
   croak unless defined wantarray;
+  my ($parent, $child) = @_;
   first { $_ == $child } $parent->d_children->@*;
 }
 
-sub is_fulfilled_with($v, $p) : Export {
+sub is_fulfilled_with : Export {
   croak unless defined wantarray;
+  my ($v, $p) = @_;
   return unless $p->d_settled && $p->{state} eq FULFILLED;
   my $dv = $p->d_v;
   return defined $dv ? $v eq $dv : !defined $dv;
 }
 
-sub is_rejected_with($v, $p) : Export {
+sub is_rejected_with : Export {
   croak unless defined wantarray;
+  my ($v, $p) = @_;
   return unless $p->d_settled && $p->{state} eq REJECTED;
   my $dv = $p->d_v;
   return defined $dv ? $v eq $dv : !defined $dv;
@@ -41,7 +44,7 @@ Evo::Promises::Util
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
