@@ -8,14 +8,16 @@ use Scalar::Util qw(refaddr blessed);
 my %REALM;
 sub REALM_DATA { \%REALM }
 
-export_gen realm => sub($key) {
+export_gen realm => sub {
+  my $key = shift;
   sub {
     return $REALM{$key} if exists $REALM{$key};
     $_[0] ? $_[0] : croak qq{not in realm of "$key"};
   };
 };
 
-export_gen realm_run => sub($key) {
+export_gen realm_run => sub {
+  my $key = shift;
   sub {
     my ($obj, $fn) = (shift, pop);
     ref $obj eq $key or croak qq{Broken REALM "$obj" isn't instance of "$key"};
@@ -38,7 +40,7 @@ Evo::Realm
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
