@@ -3,8 +3,10 @@ use Carp 'croak';
 use Evo '-Eval *', '-Export *';
 
 
-sub w_eval_run($catch) : Export {
-  sub($next) {
+sub w_eval_run : Export {
+  my $catch = shift or croak "Pass catch function";
+  sub {
+    my $next = shift;
     sub {
       my $call = eval_want(wantarray, @_, $next);
       return $call->result if $call;
@@ -28,7 +30,7 @@ Evo::W::Eval
 
 =head1 VERSION
 
-version 0.001
+version 0.0174
 
 =head1 AUTHOR
 
